#
# spec file for package python-baruwa
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-baruwa
Version:        2.0.1
Release:        3.29
Url:            http://www.topdog.za.net/baruwa
Summary:        Ajax enabled MailScanner web frontend
License:        GPL-2.0+
Group:          Development/Libraries/Python
Source:         baruwa-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-PasteScript
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       cron
Requires:       python-GeoIP
Requires:       python-PasteScript
Requires:       python-django
Requires:       python-django-south
Requires:       python-ipy
Requires:       python-lxml
Requires:       python-mysql
Requires:       python-python-dateutil
Requires:       python-reportlab
Requires:       python-uuid
Recommends:     %{name}-lang
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Baruwa (swahili for letter or mail) is a mailwatch inspired MailScanner front-end.
It provides an easy to use interface for users to view details of messages processed
by MailScanner as well as perform operations such as releasing quarantined messages,
spam learning,whitelisting and blacklisting addresses etc. Baruwa has implemented
web 2.0 features (AJAX) where deemed fit, graphing is also implemented on the client
side using SVG.
It also provides reporting functionality with an easy to use query builder, results
can be displayed as message lists or graphed as colorful and pretty graphs. The goal
of the initial version will be to address the various quarks that exist in mailwatch
at the moment. Baruwa will initially be a drop in replacement for mailwatch, future
releases will however break compatibility with mailwatch. This enables easing of
end users in to the new interface.

%lang_package

%prep
%setup -q -n baruwa-%{version}

%{__cat} <<'EOF' > baruwa.cron
#!/bin/sh
#
# %{name} - %{version}
#

# send quarantine reports
%{python_sitelib}/%{name}/manage.py sendquarantinereports
# clean quarantine 
%{python_sitelib}/%{name}/manage.py cleanquarantine
# clean up the DB
%{python_sitelib}/%{name}/manage.py dbclean
# update sa rule definitions
%{python_sitelib}/%{name}/manage.py updatesarules
# clean up stale sessions
%{python_sitelib}/%{name}/manage.py cleanup
# update geoip database
perl /usr/share/doc/GeoIP-*/fetch-geoipdata.pl
EOF

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%{__install} -D -m 0755 baruwa.cron %{buildroot}%{_sysconfdir}/cron.daily/baruwa
rm %{buildroot}%{python_sitelib}/baruwa/public/js/baruwa/.gitignore
%fdupes -s %{buildroot}%{python_sitelib}/*

%files
%defattr(-,root,root,-)
%{_bindir}/eximqf2mbox.py
%{_bindir}/import-mbox.py
%{_bindir}/test-smtpauth.py
%{_sysconfdir}/cron.daily/baruwa
%{python_sitelib}/*
%exclude %{python_sitelib}/baruwa/i18n

%files lang
%defattr(-,root,root,-)
%{python_sitelib}/baruwa/i18n

%changelog
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 2.0.1
  + No changelog available
- Add a lang subpackage
* Thu Oct 20 2011 alexandre@exatati.com.br
- Update to 1.1.1:
  * FEATURE: issue #27
  * FEATURE: Email signatures management
  * FEATURE: Support unicode subject in message logs
  * FEATURE: Add support for DB migrations with south
  * FEATURE: Experimental Message Delivery status (Relay info)
    support (exim only)
  * FEATURE: #39 Allow the recent messages value to be read from
    settings.py
  * FIX: issue #29
  * FIX: server tests
  * FIX: saving of filters
  * FIX: attachment downloads
  * FIX: exception on top hosts
  * FIX: celery worker pid directory
  * FIX: remove base from html messages
  * FIX: improve queue regex for sendmail
  * FIX: localization for mail queue status
  * FIX: database configuration documentation
  * FIX: exception on ip addrs with port numbers
  * FIX: support usernames longer than 30 characters
  * FIX: exception handling for sa-learn path issues
  * FIX: silence queuestats cron job depreciation errors
  * FIX: prevent sqlite from accepting null values from ms
  * FIX: celery jobs not completing due to repeatable read.
  * FIX: should be checking utf8subject not subject as subject is
    not being used any more.
* Fri Sep 23 2011 saschpe@suse.de
- Update to 1.1.0
- Set license to GPL-2.0+ (SPDX style)
* Sat Feb 19 2011 alexandre@exatati.com.br
- Update to 1.0.2:
  - FIX: PDF reports sending exception errors
  - FIX: Django 1.2.4 annotations regression
  - FIX: CSRF fixes to the login page.
  - FIX: Removed Javascript alert on login pag
* Thu Dec 30 2010 alexandre@exatati.com.br
- Added cron script.
* Wed Dec 29 2010 alexandre@exatati.com.br
- Update to 1.0.1:
  - FEATURE: i18n support
  - FEATURE: github request #8 password reset support
  - FEATURE: github request #7
  - added support for specifying period when sending PDF reports
  - code improvements for better performance
  - added support for update of status info via ajax
  - updated rpm spec file
  - updated debian package to support multiple web servers
  - updated documentation
  - add ability to send a copy of pdf report to the site admin
  - added support for per domain PDF reports
  - FIX: ajax message processing on IE
  - FIX: bayesian learning
  - FIX: support regex, contains, null text filters
  - FIX: github issue #6
  - FIX: github issue #5
  - FIX: github feature request #1
* Tue Oct 26 2010 alexandre@exatati.com.br
- Update to 1.0.0.
* Fri May 28 2010 alexandre@exatati.com.br
- Update to 0.0.1rc3.
* Tue May 25 2010 alexandre@exatati.com.br
- Update to 0.0.1rc2.
* Thu May 13 2010 alexandre@exatati.com.br
- Update to 0.0.1rc1.
* Mon Apr  5 2010 alexandre@exatati.com.br
- Update to 0.0.1b.
* Wed Mar 31 2010 alexandre@exatati.com.br
- Initial package (0.0.1a) for openSUSE.
